/*
 * libsyncml - A syncml protocol implementation
 * Copyright (C) 2005  Armin Bauer <armin.bauer@opensync.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; version 
 * 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 */

#include "../support.h"

#define NUM_SESSIONS 30

/* mobile status variables */

typedef enum {
	TEST_MOBILE_STATE_UNKNOWN,
	TEST_MOBILE_STATE_CONNECTED,
	TEST_MOBILE_STATE_WAIT_FOR_NOTIFICATION,
	TEST_MOBILE_STATE_WAIT_FOR_ALERT,
	TEST_MOBILE_STATE_WAIT_FOR_SYNC,
	TEST_MOBILE_STATE_WAIT_FOR_END,
	TEST_MOBILE_STATE_FINISHED,
	TEST_MOBILE_STATE_DISCONNECTED,
	TEST_MOBILE_STATE_FAILED
} SmlTestMobileStateType;

SmlTestMobileStateType mobile_state = TEST_MOBILE_STATE_UNKNOWN;

/* supported messages */

extern const char *libsyncml_msg_notification;
extern const char *mobile_msg_alert;
extern const char *libsyncml_msg_alert;
extern const char *mobile_msg_sync;
extern const char *libsyncml_msg_sync;
extern const char *mobile_msg_map;
extern const char *libsyncml_msg_end;

/* libsyncml status variables */

typedef enum {
	TEST_LIBSYNCML_STATE_UNKNOWN,
	TEST_LIBSYNCML_STATE_CONNECTED,
	TEST_LIBSYNCML_STATE_WAIT_FOR_ALERT,
	TEST_LIBSYNCML_STATE_RECEIVED_DATASTORE_SESSION,
	TEST_LIBSYNCML_STATE_RECEIVED_ALERT,
	TEST_LIBSYNCML_STATE_WAIT_FOR_SYNC,
	TEST_LIBSYNCML_STATE_WAIT_FOR_MAP,
	TEST_LIBSYNCML_STATE_FINISHED,
	TEST_LIBSYNCML_STATE_DISCONNECTED,
	TEST_LIBSYNCML_STATE_FAILED
} SmlTestLibsyncmlStateType;

SmlTestLibsyncmlStateType libsyncml_state = TEST_LIBSYNCML_STATE_UNKNOWN;

/* external parameters */

extern unsigned int max_msg_size;
extern unsigned int max_obj_size;

/* usually the OMA DS server can detect this from the client's alert */
extern SmlBool useTimestamp;

extern const char *target;
extern const char *source;

extern const char *locList[];

extern const char *mobile_name;

#include "obex_mobile_ds_server.c"
#include "obex_mobile_ds_client.c"

/* ************************************
 * *********** MOBILE TEST ************
 * ************************************
 */

START_TEST (test_mobile)
{
	/* start the server (this is the mobile) */
	obex_mobile_connect();

	/* start the client (this is libsyncml) */
	obex_libsyncml_connect();
	obex_libsyncml_send_san();
	obex_libsyncml_send_alert();
	obex_libsyncml_send_sync();
	obex_libsyncml_send_end();

	obex_mobile_disconnect();
	obex_libsyncml_disconnect();
}
END_TEST

Suite *get_test_suite(void)
{
	Suite *s = suite_create(mobile_name);
	create_case(s, mobile_name, test_mobile);
	
	return s;
}

int main(void)
{
	int nf;

	Suite *s = get_test_suite();
	
	SRunner *sr;
	sr = srunner_create(s);
	srunner_run_all(sr, CK_VERBOSE);
	nf = srunner_ntests_failed(sr);
	srunner_free(sr);
	return (nf == 0) ? 0 : 1;
}
